OC.L10N.register(
    "photos",
    {
    "Photos" : "Photos",
    "Videos" : "Video",
    "Favorites" : "Omiljeni",
    "Shared with you" : "Shared with you",
    "Tags" : "Oznake",
    "Back" : "Nazad",
    "Save" : "Sačuvaj",
    "Favorite" : "Omiljene",
    "Remove from favorites" : "Ukloni iz omiljenih",
    "Add" : "Dodaj",
    "Download" : "Preuzmi",
    "Delete" : "Obriši",
    "Settings" : "Поставке"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
